@@ -14,12 +14,12 @@ To do:
 ---------------
 
 """
-# import os
+import os
 import pkg_resources
 import numpy as np
 from .InputHipims import InputHipims
 from .OutputHipims import OutputHipims
-from .Raster import Raster
+#from hydro_raster.Raster import Raster
 
 def demo_input(num_of_sections=1, set_example_inputs=True,
                figname=None, dpi=200, **kwargs):
@@ -59,28 +59,18 @@ def demo_output(case_folder, num_of_sections=1):
                            num_of_sections=num_of_sections)
     return obj_out
 
-def demo_raster(figname=None):
-    """ A demonstration to read and show raster files
-
-    Args:
-        figname: (string) the file name to save the figure
-    """
-    dem_file = pkg_resources.resource_filename(__name__,
-                                             'sample/Example_DEM.asc')
-    obj_ras = Raster(dem_file)
-    fig, ax = obj_ras.mapshow(figname=figname, relocate=True, scale_ratio=1000)
-    ax.set_title('The Upper Lee catchment DEM (mAOD)')
-    return obj_ras
 
 def get_sample_data():
     """ Get sample data for demonstartion
 
     Returns:
-        A DEM raster object and a dictionary with boundary_condition,
-        rain_source, and gauges_pos data
+        dem_file: string for DEM file name
+        demo_data: a dictionary with boundary_condition, rain_source, and 
+            gauges_pos data
+        data_path: string the path of sample data
     """
-    dem_file = pkg_resources.resource_filename(__name__,
-                                             'sample/DEM.gz')
+    data_path = pkg_resources.resource_filename(__name__, 'sample')
+    dem_file = os.path.join(data_path, 'DEM.gz')
     demo_data = {
         'boundary_condition': [
             {'polyPoints': np.array([[1427, 195],
@@ -97,14 +87,14 @@ def get_sample_data():
         'gauges_pos': np.array([[300, 1600],
                                 [400, 1200]])
     }
-    return dem_file, demo_data
+    return dem_file, demo_data, data_path
     
 # =============private functions==================
 def __set_defaul_input(obj_in):
     """Set some default values for an InputHipims object
     """
     # load data for the demo
-    _, demo_data = get_sample_data()
+    _, demo_data, _ = get_sample_data()
     # define initial condition
     h0 = obj_in.DEM.array+0
     h0[np.isnan(h0)] = 0
